## Copyright 2021 InferStat Ltd
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Data for LBMA Gold price (USD PM fixing) obtained via Quandl.com from the London Bullion Market Association
# https://www.quandl.com/data/LBMA-London-Bullion-Market-Association
#
# Author: Thomas Oliver
# Creation date: 11th March 2021

"""
Directory for example scripts showing usages of InferTrade.
"""
